@@ -53,6 +53,7 @@ private slots:
     void interfaceExtendsMultiple();
     void staticMemberFunctionCall();
     void staticMemberVariable();
+    void dynamicStaticMemberVariable();
     void constant();
     void classConstant();
     void classParent();
@@ -89,7 +90,10 @@ private slots:
     void instanceofStaticProperty();
     void instanceofMixedProperty();
     void instanceofVariableProperty();
+    void instanceofDynamicStaticProperty();
+    void instanceofDynamicVariableProperty();
     void instanceofPropertyArrayAccess();
+    void dimListAfterClassNameReference();
     void classNameString();
     void useTrait();
     void exceptionFinally();
